@@ -9,8 +9,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Intersections_3/include/CGAL/Intersections_3/Bbox_3_Iso_cuboid_3.h $
-// $Id: Bbox_3_Iso_cuboid_3.h c2d1adf 2021-06-23T17:34:48+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.1.1/Intersections_3/include/CGAL/Intersections_3/Bbox_3_Iso_cuboid_3.h $
+// $Id: include/CGAL/Intersections_3/Bbox_3_Iso_cuboid_3.h 08b27d3db14 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -30,15 +30,17 @@
 namespace CGAL {
 
 template<typename K>
-bool do_intersect(const CGAL::Bbox_3& box,
-                  const Iso_cuboid_3<K>& ic)
+typename K::Boolean
+do_intersect(const CGAL::Bbox_3& box,
+             const Iso_cuboid_3<K>& ic)
 {
   return K().do_intersect_3_object()(box, ic);
 }
 
 template<typename K>
-bool do_intersect(const Iso_cuboid_3<K>& ic,
-                  const CGAL::Bbox_3& box)
+typename K::Boolean
+do_intersect(const Iso_cuboid_3<K>& ic,
+             const CGAL::Bbox_3& box)
 {
   return K().do_intersect_3_object()(ic, box);
 }
